==> jc-1.4.0.tar.gz: java/util/ListResourceBundle.h <==
// public abstract class java.util.ListResourceBundle

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ResourceBundle

#include "java/util/ResourceBundle.h"

#ifndef _JC_java_util_ListResourceBundle_H_
#define _JC_java_util_ListResourceBundle_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_util_ListResourceBundle$sub_refs	_jc_java_util_ListResourceBundle$sub_refs;
typedef struct _jc_java_util_ListResourceBundle$sub_nonrefs	_jc_java_util_ListResourceBundle$sub_nonrefs;
typedef struct _jc_java_util_ListResourceBundle$refs	_jc_java_util_ListResourceBundle$refs;
typedef struct _jc_java_util_ListResourceBundle$nonrefs	_jc_java_util_ListResourceBundle$nonrefs;
typedef struct _jc_java_util_ListResourceBundle$object	_jc_java_util_ListResourceBundle$object;

typedef const struct _jc_java_util_ListResourceBundle$vmethods	_jc_java_util_ListResourceBundle$vmethods;
typedef const struct _jc_java_util_ListResourceBundle$vtable	_jc_java_util_ListResourceBundle$vtable;
typedef const struct _jc_java_util_ListResourceBundle$vtype	_jc_java_util_ListResourceBundle$vtype;

// Constructors
extern void _jc_java_util_ListResourceBundle$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_ListResourceBundle$object *);

// Virtual methods
extern _jc_object_array *_jc_java_util_ListResourceBundle$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_java_util_ListResourceBundle$object *);
extern struct _jc_object *_jc_java_util_ListResourceBundle$method$getKeys$0c3e71a6b21e93a1(_jc_env *, struct _jc_java_util_ListResourceBundle$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_ListResourceBundle$method$handleGetObject$8a8018cda2e04cd4(_jc_env *, struct _jc_java_util_ListResourceBundle$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_ListResourceBundle$method_info$getContents$77295dd4f2da9d10;
extern _jc_method _jc_java_util_ListResourceBundle$method_info$getKeys$0c3e71a6b21e93a1;
extern _jc_method _jc_java_util_ListResourceBundle$method_info$handleGetObject$8a8018cda2e04cd4;

// Virtual methods structure
struct _jc_java_util_ListResourceBundle$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_java_util_ListResourceBundle$object *);
	struct _jc_object	*(*getKeys$0c3e71a6b21e93a1)(_jc_env *, struct _jc_java_util_ListResourceBundle$object *);
	struct _jc_java_lang_Object$object	*(*handleGetObject$8a8018cda2e04cd4)(_jc_env *, struct _jc_java_util_ListResourceBundle$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_java_util_ListResourceBundle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
};

// Vtype
struct _jc_java_util_ListResourceBundle$vtype {
	_jc_type			type;
	_jc_java_util_ListResourceBundle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_ListResourceBundle$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_ListResourceBundle$refs {
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_ListResourceBundle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_ListResourceBundle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
};

// Object instance structure
struct _jc_java_util_ListResourceBundle$object {
	_jc_java_util_ListResourceBundle$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_ListResourceBundle$vtype	*vtype;
	_jc_java_util_ListResourceBundle$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_ListResourceBundle$vtype _jc_java_util_ListResourceBundle$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_ListResourceBundle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_ListResourceBundle$class_object;

#endif	/* _JC_java_util_ListResourceBundle_H_ */

==> jc-1.4.6.tar.gz: java/util/ListResourceBundle.h <==
// public abstract class java.util.ListResourceBundle

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ResourceBundle

#include "java/util/ResourceBundle.h"

#ifndef _JC_java_util_ListResourceBundle_H_
#define _JC_java_util_ListResourceBundle_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_util_ListResourceBundle$sub_refs	_jc_java_util_ListResourceBundle$sub_refs;
typedef struct _jc_java_util_ListResourceBundle$sub_nonrefs	_jc_java_util_ListResourceBundle$sub_nonrefs;
typedef struct _jc_java_util_ListResourceBundle$refs	_jc_java_util_ListResourceBundle$refs;
typedef struct _jc_java_util_ListResourceBundle$nonrefs	_jc_java_util_ListResourceBundle$nonrefs;
typedef struct _jc_java_util_ListResourceBundle$object	_jc_java_util_ListResourceBundle$object;

typedef const struct _jc_java_util_ListResourceBundle$vmethods	_jc_java_util_ListResourceBundle$vmethods;
typedef const struct _jc_java_util_ListResourceBundle$vtable	_jc_java_util_ListResourceBundle$vtable;
typedef const struct _jc_java_util_ListResourceBundle$vtype	_jc_java_util_ListResourceBundle$vtype;

// Constructors
extern void _jc_java_util_ListResourceBundle$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_ListResourceBundle$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_java_util_ListResourceBundle$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_java_util_ListResourceBundle$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_ListResourceBundle$method$getKeys$0c3e71a6b21e93a1(_jc_env *, struct _jc_java_util_ListResourceBundle$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_ListResourceBundle$method$handleGetObject$8a8018cda2e04cd4(_jc_env *, struct _jc_java_util_ListResourceBundle$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_ListResourceBundle$method_info$getContents$77295dd4f2da9d10;
extern _jc_method _jc_java_util_ListResourceBundle$method_info$getKeys$0c3e71a6b21e93a1;
extern _jc_method _jc_java_util_ListResourceBundle$method_info$handleGetObject$8a8018cda2e04cd4;

// Virtual methods structure
struct _jc_java_util_ListResourceBundle$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_java_util_ListResourceBundle$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getKeys$0c3e71a6b21e93a1)(_jc_env *, struct _jc_java_util_ListResourceBundle$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*handleGetObject$8a8018cda2e04cd4)(_jc_env *, struct _jc_java_util_ListResourceBundle$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_ListResourceBundle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
};

// Vtype
struct _jc_java_util_ListResourceBundle$vtype {
	_jc_type			type;
	_jc_java_util_ListResourceBundle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_ListResourceBundle$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_ListResourceBundle$refs {
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_ListResourceBundle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_ListResourceBundle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
};

// Object instance structure
struct _jc_java_util_ListResourceBundle$object {
	_jc_java_util_ListResourceBundle$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_ListResourceBundle$vtype	*vtype;
	_jc_java_util_ListResourceBundle$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_ListResourceBundle$vtype _jc_java_util_ListResourceBundle$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_ListResourceBundle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_ListResourceBundle$class_object;

#endif	/* _JC_java_util_ListResourceBundle_H_ */
